summaryrefslogtreecommitdiff
path: root/app/Report/ReportBaseText.php
diff options
context:
space:
mode:
authorGreg Roach <fisharebest@webtrees.net>2018-10-05 14:45:31 +0100
committerGreg Roach <fisharebest@webtrees.net>2018-10-05 14:45:31 +0100
commit589feda391b943b928aea0b4107591eb0e7bbf89 (patch)
tree9181107385266814c3681d6bf53abbbdd420a592 /app/Report/ReportBaseText.php
parent1121bd6832d8a9897a30155d22c635239a794d4d (diff)
downloadwebtrees-589feda391b943b928aea0b4107591eb0e7bbf89.tar.gz
webtrees-589feda391b943b928aea0b4107591eb0e7bbf89.tar.bz2
webtrees-589feda391b943b928aea0b4107591eb0e7bbf89.zip
Strict types in reports
Diffstat (limited to 'app/Report/ReportBaseText.php')
-rw-r--r--app/Report/ReportBaseText.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/app/Report/ReportBaseText.php b/app/Report/ReportBaseText.php
index 394a266087..9bdf85ad8d 100644
--- a/app/Report/ReportBaseText.php
+++ b/app/Report/ReportBaseText.php
@@ -37,13 +37,13 @@ class ReportBaseText extends ReportBaseElement
/**
* Remaining width of a cel
*
* @var int User unit (points)
*/
public $wrapWidthRemaining;
/**
* Original width of a cell
*
* @var int User unit (points)
*/
public $wrapWidthCell;
@@ -67,9 +67,9 @@ class ReportBaseText extends ReportBaseElement
* @param $wrapwidth
* @param $cellwidth
*
- * @return int
+ * @return float
*/
- public function setWrapWidth($wrapwidth, $cellwidth): int
+ public function setWrapWidth($wrapwidth, $cellwidth): float
{
$this->wrapWidthCell = $cellwidth;
if (strpos($this->text, "\n") !== false) {
@@ -37,13 +37,13 @@ class ReportBaseText extends ReportBaseElement
* Remaining width of a cel
*
- * @var int User unit (points)
+ * @var float User unit (points)
*/
public $wrapWidthRemaining;
@@ -37,13 +37,13 @@ class ReportBaseText extends ReportBaseElement
* Original width of a cell
*
- * @var int User unit (points)
+ * @var float User unit (points)
*/
public $wrapWidthCell;